Crate druid_widget_nursery

Crate druid_widget_nursery 

A collection of widgets for the druid GUI framework

Re-exports

pub use dropdown::Dropdown;
pub use tree::Tree;
pub use tree::TreeNode;
pub use tree::TREE_NODE_REMOVE;
pub use wedge::Wedge;

Modules

animation
Druid animation library
dropdown
enum_switcher
navigator
prism
splits
stack_tooltip
A stack based tooltip widget.
table
theme_loader
Loading themes from files.
tree
A tree widget.
wedge
wrap

Macros

keys
Generates Keys based on module, line and column
loadable_theme
A macro for declaring a set of Keys that can be loaded from a file.
match_command
Matches on a command or notification.
selectors
Generates Selectors based on module, line and column

Structs

AdvancedSlider
An advanced version of the slider, allowing interactive update of a numeric value.
AutoFocus
Canvas
A container that allows for arbitrary layout.
CanvasWrap
ComputedWidget
DropdownSelect
Builds a list selection widget, showed as a button, for which the different possible values appear as a dropdown.
DynamicSizedBox
A widget that changes size dynamically; the dynamic analogue to SizedBox.
FilterIter
ListFilter
A widget which filters a list for its inner widget.
ListSelect
Builds a simple list selection widget, for selecting a single value out of a list.
Mask
A widget that conditionally masks the child content and displays other content instead (the mask).
MultiCheckbox
A Checkbox for Option instead of bool
MultiRadio
A Radio which has further configuration for the value it represents
OnChange
OnCmd
OnMonitor
This is a wrapper widget that attempts to ensure that the widget it wraps is fully contained in one monitor.
ProgressBar
A progress bar, displaying a numeric progress value.
Separator
A separator widget.
Stack
Stack of widgets
StackChildParams
Stack child configuration
StackChildPosition
Stack child position
TitleBar
A TitleBar widget.
TooltipController
A Controller responsible for listening to mouse hovers and launching tooltip windows.
Versioned
Data with explicit version.

Enums

Orientation

Traits

AnyCtx
Convenience trait for methods available on all contexts.
CanvasLayout
CommandCtx
Convenience trait for code generic over contexts.
CursorCtx
Convenience trait for cursor manipulation methods available on multiple contexts.
DynLens
A version of Lens that can be made into a trait object.
LaidOutCtx
Convenience trait for methods related to geometry and window position, available after layout.
RequestCtx
Convenience trait for invalidation and request methods available on multiple contexts.
WidgetExt

Functions

configure_env