Stack

Struct Stack 

pub struct Stack<T> { /* private fields */ }
Stack of widgets

Stack provides an easy way to stack widgets on top of each other. Children are positioned relative to the container edges.

Children are either positioned or non-positioned.

Non-positioned children are used to compute the size of the Stack widget itself. They are aligned using the Stack::align setting.

Positioned children are layed-out after non-positioned children. Their position is relative to the container edges (see StackChildPosition).

Implementations

Source

impl<T: Data> Stack<T>

pub fn new() -> Self

Create a new Stack widget.

Child alignment is set to UnitPoint::TOP_LEFT, fit and clip flags are set to false.

pub fn fit(self, fit: bool) -> Self

Builder-style method for specifying the fit attribute.

pub fn set_fit(&mut self, fit: bool)

Set the fit attribute.

Fit non-positioned children to the size of the container.

pub fn clip(self, clip: bool) -> Self

Builder-style method for specifying the clip attribute.

pub fn set_clip(&mut self, clip: bool)

Set the clip attribute.

Clip paint region at container boundaries.

pub fn align(self, align: UnitPoint) -> Self

Builder-style method for specifying the default child alignment.

pub fn set_align(&mut self, align: UnitPoint)

Set the default child alignment.

pub fn with_child(self, child: impl Widget<T> + 'static) -> Self

Builder-style variant of add_child.

pub fn add_child(&mut self, child: impl Widget<T> + 'static)

Add another stack child.

pub fn with_positioned_child( self, child: impl Widget<T> + 'static, params: impl Into<StackChildParams<T>>, ) -> Self

Builder-style variant of add_positioned_child.

pub fn add_positioned_child( &mut self, child: impl Widget<T> + 'static, params: impl Into<StackChildParams<T>>, )

Add another positioned child.