ComplexTableColumnWidth

Enum ComplexTableColumnWidth 

pub enum ComplexTableColumnWidth {
    Simple(TableColumnWidth),
    Limited(TableColumnWidth, TableColumnWidth, TableColumnWidth),
}
Table column width with optional minimum and maximum limits.

use druid_widget_nursery::table::{ComplexTableColumnWidth, TableColumnWidth::*};

// flex layout, but with minimum and maximum size
ComplexTableColumnWidth::with_min_max(Flex(1.), Fixed(100.), Fixed(300.));

// flex layout, but use intrinsic size a minimum
ComplexTableColumnWidth::with_min(Flex(1.), Intrinsic);

It is usually not necessary to use this type directly, because thert are function to convert from:

  • f64 => Simple(Fixed(f64))
  • Into<TableColumnWidth> => Simple(TableColumnWidth))
  • (Into<TableColumnWidth>, Range<f64>) => Limited with min/max from range
  • (Into<TableColumnWidth>, Into<TableColumnWidth>) => Limited with minimun
  • (Into<TableColumnWidth>, Into<TableColumnWidth>, Into<TableColumnWidth>) => Limited with min/max

Examples:

use druid_widget_nursery::table::{FlexTable, TableColumnWidth::*};
FlexTable::new()
   .with_column_width(64.0)
   .with_column_width(Intrinsic)
   .with_column_width((Flex(1.0), 60.0))
   .with_column_width((Flex(1.0), 60.0..200.0))

Variants



Simple(TableColumnWidth)

Column without limits



Limited(TableColumnWidth, TableColumnWidth, TableColumnWidth)

Limited column (width, min, max)

It is usually better to avoid flex dependent ‘min’ and ‘max’ constraint, because it can lead to unexpected results (with the current resolver).

Implementations

Source

impl ComplexTableColumnWidth

pub fn simple(tcw: TableColumnWidth) -> Self

Create instance without limits

pub fn with_min<W1, W2>(tcw: W1, min: W2) -> Self

Create instance with minimum limit

pub fn with_max<W1, W2>(tcw: W1, max: W2) -> Self

Create instance with maximum limit

pub fn with_min_max<W1, W2, W3>(tcw: W1, min: W2, max: W3) -> Self

Create instance with minimum and maximum limit