A collection of widgets for the druid GUI framework
Re-exports
pub use dropdown::Dropdown;pub use tree::Tree;pub use tree::TreeNode;pub use tree::TREE_NODE_REMOVE;pub use wedge::Wedge;
Modules
- animation
- Druid animation library
- dropdown
- enum_
switcher - navigator
- prism
- splits
- stack_
tooltip - A stack based tooltip widget.
- table
- theme_
loader - Loading themes from files.
- tree
- A tree widget.
- wedge
- wrap
Macros
- keys
- Generates
Keys based on module, line and column - loadable_
theme - A macro for declaring a set of
Keys that can be loaded from a file. - match_
command - Matches on a command or notification.
- selectors
- Generates
Selectors based on module, line and column
Structs
- Advanced
Slider - An advanced version of the slider, allowing interactive update of a numeric value.
- Auto
Focus - Canvas
- A container that allows for arbitrary layout.
- Canvas
Wrap - Computed
Widget - Dropdown
Select - Builds a list selection widget, showed as a button, for which the different possible values appear as a dropdown.
- Dynamic
Sized Box - A widget that changes size dynamically; the dynamic analogue to
SizedBox. - Filter
Iter - List
Filter - A widget which filters a list for its inner widget.
- List
Select - Builds a simple list selection widget, for selecting a single value out of a list.
- Mask
- A widget that conditionally masks the child content and displays other content instead (the mask).
- Multi
Checkbox - A Checkbox for Option instead of bool
- Multi
Radio - A Radio which has further configuration for the value it represents
- OnChange
- OnCmd
- OnMonitor
- This is a wrapper widget that attempts to ensure that the widget it wraps is fully contained in one monitor.
- Progress
Bar - A progress bar, displaying a numeric progress value.
- Separator
- A separator widget.
- Stack
- Stack of widgets
- Stack
Child Params - Stack child configuration
- Stack
Child Position - Stack child position
- Title
Bar - A TitleBar widget.
- Tooltip
Controller - A
Controllerresponsible for listening to mouse hovers and launching tooltip windows. - Versioned
- Data with explicit version.
Enums
Traits
- AnyCtx
- Convenience trait for methods available on all contexts.
- Canvas
Layout - Command
Ctx - Convenience trait for code generic over contexts.
- Cursor
Ctx - Convenience trait for cursor manipulation methods available on multiple contexts.
- DynLens
- A version of Lens that can be made into a trait object.
- Laid
OutCtx - Convenience trait for methods related to geometry and window position, available after
layout. - Request
Ctx - Convenience trait for invalidation and request methods available on multiple contexts.
- Widget
Ext