pub struct Stack<T> { /* private fields */ }Expand description
Stack of widgets
Stack provides an easy way to stack widgets on top of each other. Children are positioned relative to the container edges.
Children are either positioned or non-positioned.
Non-positioned children are used to compute the size of the Stack widget itself. They are aligned using the Stack::align setting.
Positioned children are layed-out after non-positioned
children. Their position is relative to the container edges (see
StackChildPosition).
Implementations
Sourceimpl<T: Data> Stack<T>
impl<T: Data> Stack<T>
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new Stack widget.
Child alignment is set to UnitPoint::TOP_LEFT, fit and
clip flags are set to false.
Sourcepub fn set_fit(&mut self, fit: bool)
pub fn set_fit(&mut self, fit: bool)
Set the fit attribute.
Fit non-positioned children to the size of the container.
Sourcepub fn set_clip(&mut self, clip: bool)
pub fn set_clip(&mut self, clip: bool)
Set the clip attribute.
Clip paint region at container boundaries.
Sourcepub fn align(self, align: UnitPoint) -> Self
pub fn align(self, align: UnitPoint) -> Self
Builder-style method for specifying the default child alignment.
Sourcepub fn with_child(self, child: impl Widget<T> + 'static) -> Self
pub fn with_child(self, child: impl Widget<T> + 'static) -> Self
Builder-style variant of add_child.
Sourcepub fn with_positioned_child(
self,
child: impl Widget<T> + 'static,
params: impl Into<StackChildParams<T>>,
) -> Self
pub fn with_positioned_child( self, child: impl Widget<T> + 'static, params: impl Into<StackChildParams<T>>, ) -> Self
Builder-style variant of add_positioned_child.
Sourcepub fn add_positioned_child(
&mut self,
child: impl Widget<T> + 'static,
params: impl Into<StackChildParams<T>>,
)
pub fn add_positioned_child( &mut self, child: impl Widget<T> + 'static, params: impl Into<StackChildParams<T>>, )
Add another positioned child.