pub struct StackChildPosition {
pub left: Option<f64>,
pub right: Option<f64>,
pub top: Option<f64>,
pub bottom: Option<f64>,
pub width: Option<f64>,
pub height: Option<f64>,
}Expand description
Stack child position
Stack children are positioned relative to the container edges.
Horizontal position is determined by (left, right, width). Maximal two of those values may be defined (one value need
to be None).
Vertical position is determined by (top, bottom, height). Maximal two of those values may be defined (one value
need to be None).
If width or height is unconstrained, they are positioned
according to the Stack::align property.
Fields
left: Option<f64>Disance from left edge.
right: Option<f64>Disance from right edge.
top: Option<f64>Disance from top edge.
bottom: Option<f64>Disance from bottom edge.
width: Option<f64>Widget width.
height: Option<f64>Widhet height.
Implementations
Sourceimpl StackChildPosition
impl StackChildPosition
Sourcepub fn left(self, value: Option<f64>) -> Self
pub fn left(self, value: Option<f64>) -> Self
Builder-style method to set distance from left edge.
Sourcepub fn right(self, value: Option<f64>) -> Self
pub fn right(self, value: Option<f64>) -> Self
Builder-style method to set distance from right edge.
Sourcepub fn top(self, value: Option<f64>) -> Self
pub fn top(self, value: Option<f64>) -> Self
Builder-style method to set distance from top edge.